@@ -3,6 +3,7 @@ import os
 from sanic import Sanic
 from tortoise import Tortoise, Model, fields, functions, queryset
 from tortoise.backends.base.client import BaseDBAsyncClient
+from tortoise.backends.base.config_generator import generate_config
 from tortoise.manager import Manager as ModelManager
 
 
@@ -30,7 +31,14 @@ async def init_db_connection() -> BaseDBAsyncClient:
         if os.path.exists(f'src/{blueprint_name}/models.py'):
             blueprint_models[blueprint_name] = [f'{blueprint_name}.models']
 
-    await Tortoise.init(db_url=database_url, modules={'models': blueprint_models})
+    # @TODO: Fix this ugly hack. Tortoise doesn't like empty modules so we trick it
+    if len(blueprint_models.keys()) == 0:
+        blueprint_models = {'models': {}}
+
+    import json
+    print(json.dumps(generate_config(database_url, blueprint_models), indent=2))
+
+    await Tortoise.init(db_url=database_url, modules=blueprint_models)
     return get_db_connection()
 
 async def close_db_connection() -> None:
