@@ -1,7 +1,12 @@
 """Common classes and methods used in framework."""
-from collections.abc import Generator
+import asyncio
+import importlib
+from collections.abc import AsyncGenerator, Coroutine, Generator
+from contextlib import asynccontextmanager
 from typing import Any
 
+from insanic.app import Application
+
 class ContainerField:
     """Common class for Form and Serializer."""
     def __init__(self, source: str | None = None):
@@ -11,7 +16,7 @@ class Container:
     FIELD_BASE_CLASS = ContainerField
     RESERVED_ATTRS: list[str] = []
 
-    def __init__(self, *args: tuple, **kwargs: dict) -> None: # pylint: disable=unused-argument
+    def __init__(self, *args: Any, **kwargs: Any) -> None: # pylint: disable=unused-argument
         # List of declared fields
         self._field_names = [
             attribute
@@ -36,3 +41,25 @@ def get_property_value(entity: dict | object, key: str) -> Any:
         return entity.get(key, None)
 
     return getattr(entity, key, None)
+
+def run_async(coroutine: Coroutine) -> Any:
+    return asyncio.run(coroutine)
+
+def load_application() -> Application:
+    app_module = importlib.import_module('app', package='src')  # importing src/app.py
+    application: Application = getattr(app_module, 'application')
+
+    return application
+
+@asynccontextmanager
+async def application_context() -> AsyncGenerator:
+    application = load_application()
+    loop = asyncio.get_running_loop()
+
+    await application.boot(application, loop)
+    try:
+        yield application
+    except Exception as error:
+        raise error
+    finally:
+        await application.shutdown(application, loop)
